.. Example documentation master file, created by
   sphinx-quickstart on Mon Jan  7 18:04:48 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Ripcord's documentation!
===================================

Contents:

.. toctree::
   :maxdepth: 2

API Complete Reference
======================

.. toctree::
   :maxdepth: 1

   api/index

Developers Docs
===============

.. toctree::
   :maxdepth: 1

   devref/index

Man pages
=========

.. toctree::
   :maxdepth: 1

   man/ripcord-api
   man/ripcord-manage

Modules
=======

.. toctree::
   :maxdepth: 1

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
